"""The calibrate commands module.

These commands are used in the following models:
DPO4K, DPO4KB, MDO3, MDO3K, MDO4K, MDO4KB, MDO4KC, MSO4K, MSO4KB

THIS FILE IS AUTO-GENERATED, IT SHOULD NOT BE MANUALLY MODIFIED.

Please report an issue if one is found.

Commands and Queries:
    ```
    - CALibrate:FACtory:AFG:VALue <NR3>
    - CALibrate:FACtory:STATus:AFG?
    - CALibrate:FACtory:STATus:RF?
    - CALibrate:FACtory:STATus:SCOPE?
    - CALibrate:FACtory:STATus?
    - CALibrate:INTERNal
    - CALibrate:INTERNal:STARt
    - CALibrate:INTERNal:STATus:RF?
    - CALibrate:INTERNal:STATus:SCOPE?
    - CALibrate:INTERNal:STATus?
    - CALibrate:POWerupstatus?
    - CALibrate:RESults:FACtory:AFG?
    - CALibrate:RESults:FACtory:RF?
    - CALibrate:RESults:FACtory:SCOPE?
    - CALibrate:RESults:FACtory?
    - CALibrate:RESults:SPC:RF?
    - CALibrate:RESults:SPC:SCOPE?
    - CALibrate:RESults:SPC?
    - CALibrate:RESults?
    - CALibrate:RF
    - CALibrate:RF:STARt
    - CALibrate:RF:STATus?
    - CALibrate:TEMPerature?
    ```
"""

from typing import Optional, TYPE_CHECKING

from ..helpers import SCPICmdRead, SCPICmdWrite, SCPICmdWriteNoArguments

if TYPE_CHECKING:
    from tm_devices.driver_mixins.device_control.pi_control import PIControl


class CalibrateTemperature(SCPICmdRead):
    """The ``CALibrate:TEMPerature`` command.

    Description:
        - Returns the oscilloscope temperature at the time the SPC was run.

    Usage:
        - Using the ``.query()`` method will send the ``CALibrate:TEMPerature?`` query.
        - Using the ``.verify(value)`` method will send the ``CALibrate:TEMPerature?`` query and
          raise an AssertionError if the returned value does not match ``value``.

    SCPI Syntax:
        ```
        - CALibrate:TEMPerature?
        ```
    """


class CalibrateRfStatus(SCPICmdRead):
    """The ``CALibrate:RF:STATus`` command.

    Description:
        - This query returns the status of the last RF calibration.

    Usage:
        - Using the ``.query()`` method will send the ``CALibrate:RF:STATus?`` query.
        - Using the ``.verify(value)`` method will send the ``CALibrate:RF:STATus?`` query and raise
          an AssertionError if the returned value does not match ``value``.

    SCPI Syntax:
        ```
        - CALibrate:RF:STATus?
        ```
    """


class CalibrateRfStart(SCPICmdWriteNoArguments):
    """The ``CALibrate:RF:STARt`` command.

    Description:
        - This command is identical to ``CALIBRATE:RF``.

    Usage:
        - Using the ``.write()`` method will send the ``CALibrate:RF:STARt`` command.

    SCPI Syntax:
        ```
        - CALibrate:RF:STARt
        ```
    """


class CalibrateRf(SCPICmdWriteNoArguments, SCPICmdRead):
    """The ``CALibrate:RF`` command.

    Description:
        - This command begins the RF calibration process. You should first disconnect all cables and
          probes from the RF input before using this command. The calibration process takes
          approximately 3 minutes. This command is identical to ``CALibrate:RF:STARt``.

    Usage:
        - Using the ``.write()`` method will send the ``CALibrate:RF`` command.

    SCPI Syntax:
        ```
        - CALibrate:RF
        ```

    Properties:
        - ``.start``: The ``CALibrate:RF:STARt`` command.
        - ``.status``: The ``CALibrate:RF:STATus`` command.
    """

    def __init__(self, device: Optional["PIControl"], cmd_syntax: str) -> None:
        super().__init__(device, cmd_syntax)
        self._start = CalibrateRfStart(device, f"{self._cmd_syntax}:STARt")
        self._status = CalibrateRfStatus(device, f"{self._cmd_syntax}:STATus")

    @property
    def start(self) -> CalibrateRfStart:
        """Return the ``CALibrate:RF:STARt`` command.

        Description:
            - This command is identical to ``CALIBRATE:RF``.

        Usage:
            - Using the ``.write()`` method will send the ``CALibrate:RF:STARt`` command.

        SCPI Syntax:
            ```
            - CALibrate:RF:STARt
            ```
        """
        return self._start

    @property
    def status(self) -> CalibrateRfStatus:
        """Return the ``CALibrate:RF:STATus`` command.

        Description:
            - This query returns the status of the last RF calibration.

        Usage:
            - Using the ``.query()`` method will send the ``CALibrate:RF:STATus?`` query.
            - Using the ``.verify(value)`` method will send the ``CALibrate:RF:STATus?`` query and
              raise an AssertionError if the returned value does not match ``value``.

        SCPI Syntax:
            ```
            - CALibrate:RF:STATus?
            ```
        """
        return self._status


class CalibrateResultsSpcScope(SCPICmdRead):
    """The ``CALibrate:RESults:SPC:SCOPE`` command.

    Description:
        - This query returns the status of the last SPC run for the oscilloscope portion of the
          instrument (doesn't include the RF portion). This query is synonymous to
          ``CALibrate:INTERNal:STATus:SCOPE?``

    Usage:
        - Using the ``.query()`` method will send the ``CALibrate:RESults:SPC:SCOPE?`` query.
        - Using the ``.verify(value)`` method will send the ``CALibrate:RESults:SPC:SCOPE?`` query
          and raise an AssertionError if the returned value does not match ``value``.

    SCPI Syntax:
        ```
        - CALibrate:RESults:SPC:SCOPE?
        ```
    """


class CalibrateResultsSpcRf(SCPICmdRead):
    """The ``CALibrate:RESults:SPC:RF`` command.

    Description:
        - This query returns the status of the last SPC run for the RF portion of the instrument
          (doesn't include analog channels) . This query is synonymous with
          ``CALibrate:INTERNal:STATus:RF?``

    Usage:
        - Using the ``.query()`` method will send the ``CALibrate:RESults:SPC:RF?`` query.
        - Using the ``.verify(value)`` method will send the ``CALibrate:RESults:SPC:RF?`` query and
          raise an AssertionError if the returned value does not match ``value``.

    SCPI Syntax:
        ```
        - CALibrate:RESults:SPC:RF?
        ```
    """


class CalibrateResultsSpc(SCPICmdRead):
    """The ``CALibrate:RESults:SPC`` command.

    Description:
        - Returns the status of the SPC operation. This query does not initiate a SPC.

    Usage:
        - Using the ``.query()`` method will send the ``CALibrate:RESults:SPC?`` query.
        - Using the ``.verify(value)`` method will send the ``CALibrate:RESults:SPC?`` query and
          raise an AssertionError if the returned value does not match ``value``.

    SCPI Syntax:
        ```
        - CALibrate:RESults:SPC?
        ```

    Properties:
        - ``.rf``: The ``CALibrate:RESults:SPC:RF`` command.
        - ``.scope``: The ``CALibrate:RESults:SPC:SCOPE`` command.
    """

    def __init__(self, device: Optional["PIControl"], cmd_syntax: str) -> None:
        super().__init__(device, cmd_syntax)
        self._rf = CalibrateResultsSpcRf(device, f"{self._cmd_syntax}:RF")
        self._scope = CalibrateResultsSpcScope(device, f"{self._cmd_syntax}:SCOPE")

    @property
    def rf(self) -> CalibrateResultsSpcRf:
        """Return the ``CALibrate:RESults:SPC:RF`` command.

        Description:
            - This query returns the status of the last SPC run for the RF portion of the instrument
              (doesn't include analog channels) . This query is synonymous with
              ``CALibrate:INTERNal:STATus:RF?``

        Usage:
            - Using the ``.query()`` method will send the ``CALibrate:RESults:SPC:RF?`` query.
            - Using the ``.verify(value)`` method will send the ``CALibrate:RESults:SPC:RF?`` query
              and raise an AssertionError if the returned value does not match ``value``.

        SCPI Syntax:
            ```
            - CALibrate:RESults:SPC:RF?
            ```
        """
        return self._rf

    @property
    def scope(self) -> CalibrateResultsSpcScope:
        """Return the ``CALibrate:RESults:SPC:SCOPE`` command.

        Description:
            - This query returns the status of the last SPC run for the oscilloscope portion of the
              instrument (doesn't include the RF portion). This query is synonymous to
              ``CALibrate:INTERNal:STATus:SCOPE?``

        Usage:
            - Using the ``.query()`` method will send the ``CALibrate:RESults:SPC:SCOPE?`` query.
            - Using the ``.verify(value)`` method will send the ``CALibrate:RESults:SPC:SCOPE?``
              query and raise an AssertionError if the returned value does not match ``value``.

        SCPI Syntax:
            ```
            - CALibrate:RESults:SPC:SCOPE?
            ```
        """
        return self._scope


class CalibrateResultsFactoryScope(SCPICmdRead):
    """The ``CALibrate:RESults:FACtory:SCOPE`` command.

    Description:
        - This query returns the factory calibration status for the oscilloscope (doesn't include RF
          or AFG) of the instrument. This query is synonymous with the following query:
          ``:CALibrateFACtory:STATus:SCOPE?``

    Usage:
        - Using the ``.query()`` method will send the ``CALibrate:RESults:FACtory:SCOPE?`` query.
        - Using the ``.verify(value)`` method will send the ``CALibrate:RESults:FACtory:SCOPE?``
          query and raise an AssertionError if the returned value does not match ``value``.

    SCPI Syntax:
        ```
        - CALibrate:RESults:FACtory:SCOPE?
        ```
    """


class CalibrateResultsFactoryRf(SCPICmdRead):
    """The ``CALibrate:RESults:FACtory:RF`` command.

    Description:
        - This query returns the factory calibration status for the RF portion of the instrument, if
          present. This query is synonymous with ``CALibrate:FACtory:STATus:RF?``

    Usage:
        - Using the ``.query()`` method will send the ``CALibrate:RESults:FACtory:RF?`` query.
        - Using the ``.verify(value)`` method will send the ``CALibrate:RESults:FACtory:RF?`` query
          and raise an AssertionError if the returned value does not match ``value``.

    SCPI Syntax:
        ```
        - CALibrate:RESults:FACtory:RF?
        ```
    """


class CalibrateResultsFactoryAfg(SCPICmdRead):
    """The ``CALibrate:RESults:FACtory:AFG`` command.

    Description:
        - This query returns the factory calibration status for the Arbitrary Function Generator
          portion of the instrument, if present. This query is synonymous with
          ``CALibrate:FACtory:STATus:AFG?``

    Usage:
        - Using the ``.query()`` method will send the ``CALibrate:RESults:FACtory:AFG?`` query.
        - Using the ``.verify(value)`` method will send the ``CALibrate:RESults:FACtory:AFG?`` query
          and raise an AssertionError if the returned value does not match ``value``.

    SCPI Syntax:
        ```
        - CALibrate:RESults:FACtory:AFG?
        ```
    """


class CalibrateResultsFactory(SCPICmdRead):
    """The ``CALibrate:RESults:FACtory`` command.

    Description:
        - Returns the status of internal and factory calibration, without performing any calibration
          operations.

    Usage:
        - Using the ``.query()`` method will send the ``CALibrate:RESults:FACtory?`` query.
        - Using the ``.verify(value)`` method will send the ``CALibrate:RESults:FACtory?`` query and
          raise an AssertionError if the returned value does not match ``value``.

    SCPI Syntax:
        ```
        - CALibrate:RESults:FACtory?
        ```

    Properties:
        - ``.afg``: The ``CALibrate:RESults:FACtory:AFG`` command.
        - ``.rf``: The ``CALibrate:RESults:FACtory:RF`` command.
        - ``.scope``: The ``CALibrate:RESults:FACtory:SCOPE`` command.
    """

    def __init__(self, device: Optional["PIControl"], cmd_syntax: str) -> None:
        super().__init__(device, cmd_syntax)
        self._afg = CalibrateResultsFactoryAfg(device, f"{self._cmd_syntax}:AFG")
        self._rf = CalibrateResultsFactoryRf(device, f"{self._cmd_syntax}:RF")
        self._scope = CalibrateResultsFactoryScope(device, f"{self._cmd_syntax}:SCOPE")

    @property
    def afg(self) -> CalibrateResultsFactoryAfg:
        """Return the ``CALibrate:RESults:FACtory:AFG`` command.

        Description:
            - This query returns the factory calibration status for the Arbitrary Function Generator
              portion of the instrument, if present. This query is synonymous with
              ``CALibrate:FACtory:STATus:AFG?``

        Usage:
            - Using the ``.query()`` method will send the ``CALibrate:RESults:FACtory:AFG?`` query.
            - Using the ``.verify(value)`` method will send the ``CALibrate:RESults:FACtory:AFG?``
              query and raise an AssertionError if the returned value does not match ``value``.

        SCPI Syntax:
            ```
            - CALibrate:RESults:FACtory:AFG?
            ```
        """
        return self._afg

    @property
    def rf(self) -> CalibrateResultsFactoryRf:
        """Return the ``CALibrate:RESults:FACtory:RF`` command.

        Description:
            - This query returns the factory calibration status for the RF portion of the
              instrument, if present. This query is synonymous with ``CALibrate:FACtory:STATus:RF?``

        Usage:
            - Using the ``.query()`` method will send the ``CALibrate:RESults:FACtory:RF?`` query.
            - Using the ``.verify(value)`` method will send the ``CALibrate:RESults:FACtory:RF?``
              query and raise an AssertionError if the returned value does not match ``value``.

        SCPI Syntax:
            ```
            - CALibrate:RESults:FACtory:RF?
            ```
        """
        return self._rf

    @property
    def scope(self) -> CalibrateResultsFactoryScope:
        """Return the ``CALibrate:RESults:FACtory:SCOPE`` command.

        Description:
            - This query returns the factory calibration status for the oscilloscope (doesn't
              include RF or AFG) of the instrument. This query is synonymous with the following
              query: ``:CALibrateFACtory:STATus:SCOPE?``

        Usage:
            - Using the ``.query()`` method will send the ``CALibrate:RESults:FACtory:SCOPE?``
              query.
            - Using the ``.verify(value)`` method will send the ``CALibrate:RESults:FACtory:SCOPE?``
              query and raise an AssertionError if the returned value does not match ``value``.

        SCPI Syntax:
            ```
            - CALibrate:RESults:FACtory:SCOPE?
            ```
        """
        return self._scope


class CalibrateResults(SCPICmdRead):
    """The ``CALibrate:RESults`` command.

    Description:
        - Returns the status of internal and factory calibrations, without performing any
          calibration operations. The results returned do not include the calibration status of
          attached probes. The query is intended to support GO/NoGO testing of the oscilloscope
          calibration readiness: all returned results should indicate PASS status if the
          oscilloscope is 'fit for duty'. It is quite common, however, to use uncalibrated probes
          (particularly when the oscilloscope inputs are connected into a test system with coaxial
          cables).

    Usage:
        - Using the ``.query()`` method will send the ``CALibrate:RESults?`` query.
        - Using the ``.verify(value)`` method will send the ``CALibrate:RESults?`` query and raise
          an AssertionError if the returned value does not match ``value``.

    SCPI Syntax:
        ```
        - CALibrate:RESults?
        ```

    Properties:
        - ``.factory``: The ``CALibrate:RESults:FACtory`` command.
        - ``.spc``: The ``CALibrate:RESults:SPC`` command.
    """

    def __init__(self, device: Optional["PIControl"], cmd_syntax: str) -> None:
        super().__init__(device, cmd_syntax)
        self._factory = CalibrateResultsFactory(device, f"{self._cmd_syntax}:FACtory")
        self._spc = CalibrateResultsSpc(device, f"{self._cmd_syntax}:SPC")

    @property
    def factory(self) -> CalibrateResultsFactory:
        """Return the ``CALibrate:RESults:FACtory`` command.

        Description:
            - Returns the status of internal and factory calibration, without performing any
              calibration operations.

        Usage:
            - Using the ``.query()`` method will send the ``CALibrate:RESults:FACtory?`` query.
            - Using the ``.verify(value)`` method will send the ``CALibrate:RESults:FACtory?`` query
              and raise an AssertionError if the returned value does not match ``value``.

        SCPI Syntax:
            ```
            - CALibrate:RESults:FACtory?
            ```

        Sub-properties:
            - ``.afg``: The ``CALibrate:RESults:FACtory:AFG`` command.
            - ``.rf``: The ``CALibrate:RESults:FACtory:RF`` command.
            - ``.scope``: The ``CALibrate:RESults:FACtory:SCOPE`` command.
        """
        return self._factory

    @property
    def spc(self) -> CalibrateResultsSpc:
        """Return the ``CALibrate:RESults:SPC`` command.

        Description:
            - Returns the status of the SPC operation. This query does not initiate a SPC.

        Usage:
            - Using the ``.query()`` method will send the ``CALibrate:RESults:SPC?`` query.
            - Using the ``.verify(value)`` method will send the ``CALibrate:RESults:SPC?`` query and
              raise an AssertionError if the returned value does not match ``value``.

        SCPI Syntax:
            ```
            - CALibrate:RESults:SPC?
            ```

        Sub-properties:
            - ``.rf``: The ``CALibrate:RESults:SPC:RF`` command.
            - ``.scope``: The ``CALibrate:RESults:SPC:SCOPE`` command.
        """
        return self._spc


class CalibratePowerupstatus(SCPICmdRead):
    """The ``CALibrate:POWerupstatus`` command.

    Description:
        - Returns the status of the oscilloscope following power on.

    Usage:
        - Using the ``.query()`` method will send the ``CALibrate:POWerupstatus?`` query.
        - Using the ``.verify(value)`` method will send the ``CALibrate:POWerupstatus?`` query and
          raise an AssertionError if the returned value does not match ``value``.

    SCPI Syntax:
        ```
        - CALibrate:POWerupstatus?
        ```
    """


class CalibrateInternalStatusScope(SCPICmdRead):
    """The ``CALibrate:INTERNal:STATus:SCOPE`` command.

    Description:
        - This query returns the status of the last SPC run for the oscilloscope portion of the
          instrument (doesn't include the RF portion). To query the status of the RF portions, use
          ``CALIBRATE:INTERNAL:STATUS:RF This`` query is synonymous to
          ``CALIBRATE:RESULTS:SPC:SCOPE``

    Usage:
        - Using the ``.query()`` method will send the ``CALibrate:INTERNal:STATus:SCOPE?`` query.
        - Using the ``.verify(value)`` method will send the ``CALibrate:INTERNal:STATus:SCOPE?``
          query and raise an AssertionError if the returned value does not match ``value``.

    SCPI Syntax:
        ```
        - CALibrate:INTERNal:STATus:SCOPE?
        ```
    """


class CalibrateInternalStatusRf(SCPICmdRead):
    """The ``CALibrate:INTERNal:STATus:RF`` command.

    Description:
        - This query returns the status of the last SPC run for the RF portion of the instrument:
          (doesn't include the analog channels). This query is synonymous with
          ``CALibrate:RESults:SPC:RF?``

    Usage:
        - Using the ``.query()`` method will send the ``CALibrate:INTERNal:STATus:RF?`` query.
        - Using the ``.verify(value)`` method will send the ``CALibrate:INTERNal:STATus:RF?`` query
          and raise an AssertionError if the returned value does not match ``value``.

    SCPI Syntax:
        ```
        - CALibrate:INTERNal:STATus:RF?
        ```
    """


class CalibrateInternalStatus(SCPICmdRead):
    """The ``CALibrate:INTERNal:STATus`` command.

    Description:
        - This query-only command returns the current status of the signal path calibration.

    Usage:
        - Using the ``.query()`` method will send the ``CALibrate:INTERNal:STATus?`` query.
        - Using the ``.verify(value)`` method will send the ``CALibrate:INTERNal:STATus?`` query and
          raise an AssertionError if the returned value does not match ``value``.

    SCPI Syntax:
        ```
        - CALibrate:INTERNal:STATus?
        ```

    Properties:
        - ``.rf``: The ``CALibrate:INTERNal:STATus:RF`` command.
        - ``.scope``: The ``CALibrate:INTERNal:STATus:SCOPE`` command.
    """

    def __init__(self, device: Optional["PIControl"], cmd_syntax: str) -> None:
        super().__init__(device, cmd_syntax)
        self._rf = CalibrateInternalStatusRf(device, f"{self._cmd_syntax}:RF")
        self._scope = CalibrateInternalStatusScope(device, f"{self._cmd_syntax}:SCOPE")

    @property
    def rf(self) -> CalibrateInternalStatusRf:
        """Return the ``CALibrate:INTERNal:STATus:RF`` command.

        Description:
            - This query returns the status of the last SPC run for the RF portion of the
              instrument: (doesn't include the analog channels). This query is synonymous with
              ``CALibrate:RESults:SPC:RF?``

        Usage:
            - Using the ``.query()`` method will send the ``CALibrate:INTERNal:STATus:RF?`` query.
            - Using the ``.verify(value)`` method will send the ``CALibrate:INTERNal:STATus:RF?``
              query and raise an AssertionError if the returned value does not match ``value``.

        SCPI Syntax:
            ```
            - CALibrate:INTERNal:STATus:RF?
            ```
        """
        return self._rf

    @property
    def scope(self) -> CalibrateInternalStatusScope:
        """Return the ``CALibrate:INTERNal:STATus:SCOPE`` command.

        Description:
            - This query returns the status of the last SPC run for the oscilloscope portion of the
              instrument (doesn't include the RF portion). To query the status of the RF portions,
              use ``CALIBRATE:INTERNAL:STATUS:RF This`` query is synonymous to
              ``CALIBRATE:RESULTS:SPC:SCOPE``

        Usage:
            - Using the ``.query()`` method will send the ``CALibrate:INTERNal:STATus:SCOPE?``
              query.
            - Using the ``.verify(value)`` method will send the ``CALibrate:INTERNal:STATus:SCOPE?``
              query and raise an AssertionError if the returned value does not match ``value``.

        SCPI Syntax:
            ```
            - CALibrate:INTERNal:STATus:SCOPE?
            ```
        """
        return self._scope


class CalibrateInternalStart(SCPICmdWriteNoArguments):
    """The ``CALibrate:INTERNal:STARt`` command.

    Description:
        - This command (no query form) starts the signal path calibration (SPC) of the analog
          channels. This command is the same as the ``CALIBRATE:INTERNAL`` command. You can use the
          ``CALIBRATE:INTERNAL:STATUS`` query to return the current status of the signal path
          calibration of the instrument.

    Usage:
        - Using the ``.write()`` method will send the ``CALibrate:INTERNal:STARt`` command.

    SCPI Syntax:
        ```
        - CALibrate:INTERNal:STARt
        ```
    """


class CalibrateInternal(SCPICmdWriteNoArguments, SCPICmdRead):
    """The ``CALibrate:INTERNal`` command.

    Description:
        - This command (no query form) starts the signal path calibration (SPC) of the instrument.
          You can use the ``CALIBRATE:INTERNAL:STATUS`` query to return the current status of the
          signal path calibration of the instrument.

    Usage:
        - Using the ``.write()`` method will send the ``CALibrate:INTERNal`` command.

    SCPI Syntax:
        ```
        - CALibrate:INTERNal
        ```

    Properties:
        - ``.start``: The ``CALibrate:INTERNal:STARt`` command.
        - ``.status``: The ``CALibrate:INTERNal:STATus`` command.
    """

    def __init__(self, device: Optional["PIControl"], cmd_syntax: str) -> None:
        super().__init__(device, cmd_syntax)
        self._start = CalibrateInternalStart(device, f"{self._cmd_syntax}:STARt")
        self._status = CalibrateInternalStatus(device, f"{self._cmd_syntax}:STATus")

    @property
    def start(self) -> CalibrateInternalStart:
        """Return the ``CALibrate:INTERNal:STARt`` command.

        Description:
            - This command (no query form) starts the signal path calibration (SPC) of the analog
              channels. This command is the same as the ``CALIBRATE:INTERNAL`` command. You can use
              the ``CALIBRATE:INTERNAL:STATUS`` query to return the current status of the signal
              path calibration of the instrument.

        Usage:
            - Using the ``.write()`` method will send the ``CALibrate:INTERNal:STARt`` command.

        SCPI Syntax:
            ```
            - CALibrate:INTERNal:STARt
            ```
        """
        return self._start

    @property
    def status(self) -> CalibrateInternalStatus:
        """Return the ``CALibrate:INTERNal:STATus`` command.

        Description:
            - This query-only command returns the current status of the signal path calibration.

        Usage:
            - Using the ``.query()`` method will send the ``CALibrate:INTERNal:STATus?`` query.
            - Using the ``.verify(value)`` method will send the ``CALibrate:INTERNal:STATus?`` query
              and raise an AssertionError if the returned value does not match ``value``.

        SCPI Syntax:
            ```
            - CALibrate:INTERNal:STATus?
            ```

        Sub-properties:
            - ``.rf``: The ``CALibrate:INTERNal:STATus:RF`` command.
            - ``.scope``: The ``CALibrate:INTERNal:STATus:SCOPE`` command.
        """
        return self._status


class CalibrateFactoryStatusScope(SCPICmdRead):
    """The ``CALibrate:FACtory:STATus:SCOPE`` command.

    Description:
        - Returns the factory calibration status value saved in nonvolatile memory for the non-RF
          portion of the oscilloscope. It is synonymous with the
          ``:CALibrate:RESults:FACtory:SCOPE?`` query.

    Usage:
        - Using the ``.query()`` method will send the ``CALibrate:FACtory:STATus:SCOPE?`` query.
        - Using the ``.verify(value)`` method will send the ``CALibrate:FACtory:STATus:SCOPE?``
          query and raise an AssertionError if the returned value does not match ``value``.

    SCPI Syntax:
        ```
        - CALibrate:FACtory:STATus:SCOPE?
        ```
    """


class CalibrateFactoryStatusRf(SCPICmdRead):
    """The ``CALibrate:FACtory:STATus:RF`` command.

    Description:
        - Returns the factory calibration status value saved in nonvolatile memory for the RF
          portion of the oscilloscope. This query is synonymous with
          ``CALIBRATE:RESULTS:FACTORY:RF``.

    Usage:
        - Using the ``.query()`` method will send the ``CALibrate:FACtory:STATus:RF?`` query.
        - Using the ``.verify(value)`` method will send the ``CALibrate:FACtory:STATus:RF?`` query
          and raise an AssertionError if the returned value does not match ``value``.

    SCPI Syntax:
        ```
        - CALibrate:FACtory:STATus:RF?
        ```
    """


class CalibrateFactoryStatusAfg(SCPICmdRead):
    """The ``CALibrate:FACtory:STATus:AFG`` command.

    Description:
        - This query returns the factory calibration status for the Arbitrary Function Generator
          portion of the instrument, if present. This query is synonymous with
          ``CALIBRATE:RESULTS:FACTORY:AFG``

    Usage:
        - Using the ``.query()`` method will send the ``CALibrate:FACtory:STATus:AFG?`` query.
        - Using the ``.verify(value)`` method will send the ``CALibrate:FACtory:STATus:AFG?`` query
          and raise an AssertionError if the returned value does not match ``value``.

    SCPI Syntax:
        ```
        - CALibrate:FACtory:STATus:AFG?
        ```
    """


class CalibrateFactoryStatus(SCPICmdRead):
    """The ``CALibrate:FACtory:STATus`` command.

    Description:
        - Returns the factory calibration status value saved in nonvolatile memory.

    Usage:
        - Using the ``.query()`` method will send the ``CALibrate:FACtory:STATus?`` query.
        - Using the ``.verify(value)`` method will send the ``CALibrate:FACtory:STATus?`` query and
          raise an AssertionError if the returned value does not match ``value``.

    SCPI Syntax:
        ```
        - CALibrate:FACtory:STATus?
        ```

    Properties:
        - ``.afg``: The ``CALibrate:FACtory:STATus:AFG`` command.
        - ``.rf``: The ``CALibrate:FACtory:STATus:RF`` command.
        - ``.scope``: The ``CALibrate:FACtory:STATus:SCOPE`` command.
    """

    def __init__(self, device: Optional["PIControl"], cmd_syntax: str) -> None:
        super().__init__(device, cmd_syntax)
        self._afg = CalibrateFactoryStatusAfg(device, f"{self._cmd_syntax}:AFG")
        self._rf = CalibrateFactoryStatusRf(device, f"{self._cmd_syntax}:RF")
        self._scope = CalibrateFactoryStatusScope(device, f"{self._cmd_syntax}:SCOPE")

    @property
    def afg(self) -> CalibrateFactoryStatusAfg:
        """Return the ``CALibrate:FACtory:STATus:AFG`` command.

        Description:
            - This query returns the factory calibration status for the Arbitrary Function Generator
              portion of the instrument, if present. This query is synonymous with
              ``CALIBRATE:RESULTS:FACTORY:AFG``

        Usage:
            - Using the ``.query()`` method will send the ``CALibrate:FACtory:STATus:AFG?`` query.
            - Using the ``.verify(value)`` method will send the ``CALibrate:FACtory:STATus:AFG?``
              query and raise an AssertionError if the returned value does not match ``value``.

        SCPI Syntax:
            ```
            - CALibrate:FACtory:STATus:AFG?
            ```
        """
        return self._afg

    @property
    def rf(self) -> CalibrateFactoryStatusRf:
        """Return the ``CALibrate:FACtory:STATus:RF`` command.

        Description:
            - Returns the factory calibration status value saved in nonvolatile memory for the RF
              portion of the oscilloscope. This query is synonymous with
              ``CALIBRATE:RESULTS:FACTORY:RF``.

        Usage:
            - Using the ``.query()`` method will send the ``CALibrate:FACtory:STATus:RF?`` query.
            - Using the ``.verify(value)`` method will send the ``CALibrate:FACtory:STATus:RF?``
              query and raise an AssertionError if the returned value does not match ``value``.

        SCPI Syntax:
            ```
            - CALibrate:FACtory:STATus:RF?
            ```
        """
        return self._rf

    @property
    def scope(self) -> CalibrateFactoryStatusScope:
        """Return the ``CALibrate:FACtory:STATus:SCOPE`` command.

        Description:
            - Returns the factory calibration status value saved in nonvolatile memory for the
              non-RF portion of the oscilloscope. It is synonymous with the
              ``:CALibrate:RESults:FACtory:SCOPE?`` query.

        Usage:
            - Using the ``.query()`` method will send the ``CALibrate:FACtory:STATus:SCOPE?`` query.
            - Using the ``.verify(value)`` method will send the ``CALibrate:FACtory:STATus:SCOPE?``
              query and raise an AssertionError if the returned value does not match ``value``.

        SCPI Syntax:
            ```
            - CALibrate:FACtory:STATus:SCOPE?
            ```
        """
        return self._scope


class CalibrateFactoryAfgValue(SCPICmdWrite):
    """The ``CALibrate:FACtory:AFG:VALue`` command.

    Description:
        - For steps that require the measurement value of a connected DVM or frequency counter, this
          command is used to send those values to the scope calibration software.

    Usage:
        - Using the ``.write(value)`` method will send the ``CALibrate:FACtory:AFG:VALue value``
          command.

    SCPI Syntax:
        ```
        - CALibrate:FACtory:AFG:VALue <NR3>
        ```
    """


class CalibrateFactoryAfg(SCPICmdRead):
    """The ``CALibrate:FACtory:AFG`` command tree.

    Usage:
        - Using the ``.query()`` method will send the ``CALibrate:FACtory:AFG?`` query.
        - Using the ``.verify(value)`` method will send the ``CALibrate:FACtory:AFG?`` query and
          raise an AssertionError if the returned value does not match ``value``.

    Properties:
        - ``.value``: The ``CALibrate:FACtory:AFG:VALue`` command.
    """

    def __init__(self, device: Optional["PIControl"], cmd_syntax: str) -> None:
        super().__init__(device, cmd_syntax)
        self._value = CalibrateFactoryAfgValue(device, f"{self._cmd_syntax}:VALue")

    @property
    def value(self) -> CalibrateFactoryAfgValue:
        """Return the ``CALibrate:FACtory:AFG:VALue`` command.

        Description:
            - For steps that require the measurement value of a connected DVM or frequency counter,
              this command is used to send those values to the scope calibration software.

        Usage:
            - Using the ``.write(value)`` method will send the ``CALibrate:FACtory:AFG:VALue value``
              command.

        SCPI Syntax:
            ```
            - CALibrate:FACtory:AFG:VALue <NR3>
            ```
        """
        return self._value


class CalibrateFactory(SCPICmdRead):
    """The ``CALibrate:FACtory`` command tree.

    Usage:
        - Using the ``.query()`` method will send the ``CALibrate:FACtory?`` query.
        - Using the ``.verify(value)`` method will send the ``CALibrate:FACtory?`` query and raise
          an AssertionError if the returned value does not match ``value``.

    Properties:
        - ``.afg``: The ``CALibrate:FACtory:AFG`` command tree.
        - ``.status``: The ``CALibrate:FACtory:STATus`` command.
    """

    def __init__(self, device: Optional["PIControl"], cmd_syntax: str) -> None:
        super().__init__(device, cmd_syntax)
        self._afg = CalibrateFactoryAfg(device, f"{self._cmd_syntax}:AFG")
        self._status = CalibrateFactoryStatus(device, f"{self._cmd_syntax}:STATus")

    @property
    def afg(self) -> CalibrateFactoryAfg:
        """Return the ``CALibrate:FACtory:AFG`` command tree.

        Usage:
            - Using the ``.query()`` method will send the ``CALibrate:FACtory:AFG?`` query.
            - Using the ``.verify(value)`` method will send the ``CALibrate:FACtory:AFG?`` query and
              raise an AssertionError if the returned value does not match ``value``.

        Sub-properties:
            - ``.value``: The ``CALibrate:FACtory:AFG:VALue`` command.
        """
        return self._afg

    @property
    def status(self) -> CalibrateFactoryStatus:
        """Return the ``CALibrate:FACtory:STATus`` command.

        Description:
            - Returns the factory calibration status value saved in nonvolatile memory.

        Usage:
            - Using the ``.query()`` method will send the ``CALibrate:FACtory:STATus?`` query.
            - Using the ``.verify(value)`` method will send the ``CALibrate:FACtory:STATus?`` query
              and raise an AssertionError if the returned value does not match ``value``.

        SCPI Syntax:
            ```
            - CALibrate:FACtory:STATus?
            ```

        Sub-properties:
            - ``.afg``: The ``CALibrate:FACtory:STATus:AFG`` command.
            - ``.rf``: The ``CALibrate:FACtory:STATus:RF`` command.
            - ``.scope``: The ``CALibrate:FACtory:STATus:SCOPE`` command.
        """
        return self._status


class Calibrate(SCPICmdRead):
    """The ``CALibrate`` command tree.

    Usage:
        - Using the ``.query()`` method will send the ``CALibrate?`` query.
        - Using the ``.verify(value)`` method will send the ``CALibrate?`` query and raise an
          AssertionError if the returned value does not match ``value``.

    Properties:
        - ``.factory``: The ``CALibrate:FACtory`` command tree.
        - ``.internal``: The ``CALibrate:INTERNal`` command.
        - ``.powerupstatus``: The ``CALibrate:POWerupstatus`` command.
        - ``.results``: The ``CALibrate:RESults`` command.
        - ``.rf``: The ``CALibrate:RF`` command.
        - ``.temperature``: The ``CALibrate:TEMPerature`` command.
    """

    def __init__(self, device: Optional["PIControl"] = None, cmd_syntax: str = "CALibrate") -> None:
        super().__init__(device, cmd_syntax)
        self._factory = CalibrateFactory(device, f"{self._cmd_syntax}:FACtory")
        self._internal = CalibrateInternal(device, f"{self._cmd_syntax}:INTERNal")
        self._powerupstatus = CalibratePowerupstatus(device, f"{self._cmd_syntax}:POWerupstatus")
        self._results = CalibrateResults(device, f"{self._cmd_syntax}:RESults")
        self._rf = CalibrateRf(device, f"{self._cmd_syntax}:RF")
        self._temperature = CalibrateTemperature(device, f"{self._cmd_syntax}:TEMPerature")

    @property
    def factory(self) -> CalibrateFactory:
        """Return the ``CALibrate:FACtory`` command tree.

        Usage:
            - Using the ``.query()`` method will send the ``CALibrate:FACtory?`` query.
            - Using the ``.verify(value)`` method will send the ``CALibrate:FACtory?`` query and
              raise an AssertionError if the returned value does not match ``value``.

        Sub-properties:
            - ``.afg``: The ``CALibrate:FACtory:AFG`` command tree.
            - ``.status``: The ``CALibrate:FACtory:STATus`` command.
        """
        return self._factory

    @property
    def internal(self) -> CalibrateInternal:
        """Return the ``CALibrate:INTERNal`` command.

        Description:
            - This command (no query form) starts the signal path calibration (SPC) of the
              instrument. You can use the ``CALIBRATE:INTERNAL:STATUS`` query to return the current
              status of the signal path calibration of the instrument.

        Usage:
            - Using the ``.write()`` method will send the ``CALibrate:INTERNal`` command.

        SCPI Syntax:
            ```
            - CALibrate:INTERNal
            ```

        Sub-properties:
            - ``.start``: The ``CALibrate:INTERNal:STARt`` command.
            - ``.status``: The ``CALibrate:INTERNal:STATus`` command.
        """
        return self._internal

    @property
    def powerupstatus(self) -> CalibratePowerupstatus:
        """Return the ``CALibrate:POWerupstatus`` command.

        Description:
            - Returns the status of the oscilloscope following power on.

        Usage:
            - Using the ``.query()`` method will send the ``CALibrate:POWerupstatus?`` query.
            - Using the ``.verify(value)`` method will send the ``CALibrate:POWerupstatus?`` query
              and raise an AssertionError if the returned value does not match ``value``.

        SCPI Syntax:
            ```
            - CALibrate:POWerupstatus?
            ```
        """
        return self._powerupstatus

    @property
    def results(self) -> CalibrateResults:
        """Return the ``CALibrate:RESults`` command.

        Description:
            - Returns the status of internal and factory calibrations, without performing any
              calibration operations. The results returned do not include the calibration status of
              attached probes. The query is intended to support GO/NoGO testing of the oscilloscope
              calibration readiness: all returned results should indicate PASS status if the
              oscilloscope is 'fit for duty'. It is quite common, however, to use uncalibrated
              probes (particularly when the oscilloscope inputs are connected into a test system
              with coaxial cables).

        Usage:
            - Using the ``.query()`` method will send the ``CALibrate:RESults?`` query.
            - Using the ``.verify(value)`` method will send the ``CALibrate:RESults?`` query and
              raise an AssertionError if the returned value does not match ``value``.

        SCPI Syntax:
            ```
            - CALibrate:RESults?
            ```

        Sub-properties:
            - ``.factory``: The ``CALibrate:RESults:FACtory`` command.
            - ``.spc``: The ``CALibrate:RESults:SPC`` command.
        """
        return self._results

    @property
    def rf(self) -> CalibrateRf:
        """Return the ``CALibrate:RF`` command.

        Description:
            - This command begins the RF calibration process. You should first disconnect all cables
              and probes from the RF input before using this command. The calibration process takes
              approximately 3 minutes. This command is identical to ``CALibrate:RF:STARt``.

        Usage:
            - Using the ``.write()`` method will send the ``CALibrate:RF`` command.

        SCPI Syntax:
            ```
            - CALibrate:RF
            ```

        Sub-properties:
            - ``.start``: The ``CALibrate:RF:STARt`` command.
            - ``.status``: The ``CALibrate:RF:STATus`` command.
        """
        return self._rf

    @property
    def temperature(self) -> CalibrateTemperature:
        """Return the ``CALibrate:TEMPerature`` command.

        Description:
            - Returns the oscilloscope temperature at the time the SPC was run.

        Usage:
            - Using the ``.query()`` method will send the ``CALibrate:TEMPerature?`` query.
            - Using the ``.verify(value)`` method will send the ``CALibrate:TEMPerature?`` query and
              raise an AssertionError if the returned value does not match ``value``.

        SCPI Syntax:
            ```
            - CALibrate:TEMPerature?
            ```
        """
        return self._temperature



"""The unlock commands module.

These commands are used in the following models:
DPO2K, DPO2KB, DPO4K, DPO4KB, DPO5K, DPO5KB, DPO70KC, DPO70KD, DPO70KDX, DPO70KSX, DPO7K, DPO7KC,
DSA70KC, DSA70KD, MDO3K, MDO4K, MDO4KB, MDO4KC, MSO2, MSO2K, MSO2KB, MSO4K, MSO4KB, MSO5K, MSO5KB,
MSO70KC, MSO70KDX

THIS FILE IS AUTO-GENERATED, IT SHOULD NOT BE MANUALLY MODIFIED.

Please report an issue if one is found.

Commands and Queries:
    ```
    - UNLock ALL
    ```
"""

from typing import Optional, TYPE_CHECKING

from ..helpers import SCPICmdWrite

if TYPE_CHECKING:
    from tm_devices.driver_mixins.device_control.pi_control import PIControl


class Unlock(SCPICmdWrite):
    """The ``UNLock`` command.

    Description:
        - This command (no query form) unlocks the front panel controls only. To unlock the front
          panel controls and the touch screen use the LOCk NONe command. The command
          ``TOUCHSCReen:STATE ON`` enables the touch screen only.

    Usage:
        - Using the ``.write(value)`` method will send the ``UNLock value`` command.

    SCPI Syntax:
        ```
        - UNLock ALL
        ```

    Info:
        - ``ALL`` specifies that all front panel buttons and knobs are unlocked.
    """

    def __init__(self, device: Optional["PIControl"] = None, cmd_syntax: str = "UNLock") -> None:
        super().__init__(device, cmd_syntax)



# pyright: reportConstantRedefinition=none
"""The tspnet commands module.

These commands are used in the following models:
SMU2601B_Pulse

THIS FILE IS AUTO-GENERATED, IT SHOULD NOT BE MANUALLY MODIFIED.

Please report an issue if one is found.
"""

from typing import Optional, TYPE_CHECKING

from ..helpers import BaseTSPCmd

if TYPE_CHECKING:
    from tm_devices.driver_mixins.device_control.tsp_control import TSPControl


# pylint: disable=too-few-public-methods
class Tspnet(BaseTSPCmd):
    """The ``tspnet`` command tree.

    Constants:
        - ``.TERM_CR``: Set the device line termination sequence to CR.
        - ``.TERM_CRLF``: Set the device line termination sequence to CRLF.
        - ``.TERM_LF``: Set the device line termination sequence to LF.
        - ``.TERM_LFCR``: Set the device line termination sequence to LFCR.
    """

    TERM_CR = "tspnet.TERM_CR"
    """str: Set the device line termination sequence to CR."""
    TERM_CRLF = "tspnet.TERM_CRLF"
    """str: Set the device line termination sequence to CRLF."""
    TERM_LF = "tspnet.TERM_LF"
    """str: Set the device line termination sequence to LF."""
    TERM_LFCR = "tspnet.TERM_LFCR"
    """str: Set the device line termination sequence to LFCR."""

    def __init__(self, device: Optional["TSPControl"] = None, cmd_syntax: str = "tspnet") -> None:
        super().__init__(device, cmd_syntax)



# pyright: reportConstantRedefinition=none
"""The file commands module.

These commands are used in the following models:
DAQ6510, DMM6500, DMM7510, SMU2450, SMU2460, SMU2461, SMU2470

THIS FILE IS AUTO-GENERATED, IT SHOULD NOT BE MANUALLY MODIFIED.

Please report an issue if one is found.

Attributes and Functions:
    ```
    - file.close()
    - file.flush()
    - file.mkdir()
    - file.open()
    - file.read()
    - file.usbdriveexists()
    - file.write()
    ```
"""

from typing import Optional, TYPE_CHECKING

from ..helpers import BaseTSPCmd, NoDeviceProvidedError

if TYPE_CHECKING:
    from tm_devices.driver_mixins.device_control.tsp_control import TSPControl


class File(BaseTSPCmd):
    """The ``file`` command tree.

    Constants:
        - ``.MODE_APPEND``: Append the file.
        - ``.MODE_READ``: Read the file.
        - ``.MODE_WRITE``: Write to the file.
        - ``.READ_ALL``: Return the whole file, starting at the present position; returns nil if the
          present file position is at the end of the file.
        - ``.READ_LINE``: Return the next line; returns nil if the present file position is at the
          end of the file.
        - ``.READ_NUMBER``: Return a string that represents the number found; returns an event
          string if no number was found; returns nil if the current file position is at the end of
          file.

    Properties and methods:
        - ``.close()``: The ``file.close()`` function.
        - ``.flush()``: The ``file.flush()`` function.
        - ``.mkdir()``: The ``file.mkdir()`` function.
        - ``.open()``: The ``file.open()`` function.
        - ``.read()``: The ``file.read()`` function.
        - ``.usbdriveexists()``: The ``file.usbdriveexists()`` function.
        - ``.write()``: The ``file.write()`` function.
    """

    MODE_APPEND = "file.MODE_APPEND"
    """str: Append the file."""
    MODE_READ = "file.MODE_READ"
    """str: Read the file."""
    MODE_WRITE = "file.MODE_WRITE"
    """str: Write to the file."""
    READ_ALL = "file.READ_ALL"
    """str: Return the whole file, starting at the present position; returns nil if the present file position is at the end of the file."""  # noqa: E501
    READ_LINE = "file.READ_LINE"
    """str: Return the next line; returns nil if the present file position is at the end of the file."""  # noqa: E501
    READ_NUMBER = "file.READ_NUMBER"
    """str: Return a string that represents the number found; returns an event string if no number was found; returns nil if the current file position is at the end of file."""  # noqa: E501

    def __init__(self, device: Optional["TSPControl"] = None, cmd_syntax: str = "file") -> None:
        super().__init__(device, cmd_syntax)

    def close(self, file_number: int) -> None:
        """Run the ``file.close()`` function.

        Description:
            - This function closes a file on the USB flash drive.

        TSP Syntax:
            ```
            - file.close()
            ```

        Args:
            file_number: The file number returned from the file.open() function to close.

        Raises:
            tm_devices.commands.NoDeviceProvidedError: Indicates that no device connection exists.
        """
        try:
            self._device.write(  # type: ignore[union-attr]
                f"{self._cmd_syntax}.close({file_number})"
            )
        except AttributeError as error:
            msg = f"No TSPControl object was provided, unable to run the ``{self._cmd_syntax}.close()`` function."  # noqa: E501
            raise NoDeviceProvidedError(msg) from error

    def flush(self, file_number: int) -> None:
        """Run the ``file.flush()`` function.

        Description:
            - This function writes buffering data to a file on the USB flash drive.

        TSP Syntax:
            ```
            - file.flush()
            ```

        Args:
            file_number: The file number returned from the file.open() function to flush.

        Raises:
            tm_devices.commands.NoDeviceProvidedError: Indicates that no device connection exists.
        """
        try:
            self._device.write(  # type: ignore[union-attr]
                f"{self._cmd_syntax}.flush({file_number})"
            )
        except AttributeError as error:
            msg = f"No TSPControl object was provided, unable to run the ``{self._cmd_syntax}.flush()`` function."  # noqa: E501
            raise NoDeviceProvidedError(msg) from error

    def mkdir(self, path: str) -> None:
        """Run the ``file.mkdir()`` function.

        Description:
            - This function creates a directory at the specified path on the USB flash drive.

        TSP Syntax:
            ```
            - file.mkdir()
            ```

        Args:
            path: A string that contains the path of the directory.

        Raises:
            tm_devices.commands.NoDeviceProvidedError: Indicates that no device connection exists.
        """
        try:
            self._device.write(  # type: ignore[union-attr]
                f'{self._cmd_syntax}.mkdir("{path}")'
            )
        except AttributeError as error:
            msg = f"No TSPControl object was provided, unable to run the ``{self._cmd_syntax}.mkdir()`` function."  # noqa: E501
            raise NoDeviceProvidedError(msg) from error

    def open(self, file_name: str, access_type: str) -> str:
        """Run the ``file.open()`` function.

        Description:
            - This function opens a file on the USB flash drive for later reference.

        TSP Syntax:
            ```
            - file.open()
            ```

        Args:
            file_name: A string that contains the file name to open, including the full path of
                file.
            access_type: The type of action to do.

        Returns:
            The result of the function call.

        Raises:
            tm_devices.commands.NoDeviceProvidedError: Indicates that no device connection exists.
        """
        try:
            return self._device.query(  # type: ignore[union-attr]
                f'print({self._cmd_syntax}.open("{file_name}", {access_type}))'
            )
        except AttributeError as error:
            msg = f"No TSPControl object was provided, unable to run the ``{self._cmd_syntax}.open()`` function."  # noqa: E501
            raise NoDeviceProvidedError(msg) from error

    def read(self, file_number: int, read_action: str) -> str:
        """Run the ``file.read()`` function.

        Description:
            - This function reads data from a file on the USB flash drive.

        TSP Syntax:
            ```
            - file.read()
            ```

        Args:
            file_number: The file number returned from the file.open() function to read.
            read_action: The action.

        Returns:
            The result of the function call.

        Raises:
            tm_devices.commands.NoDeviceProvidedError: Indicates that no device connection exists.
        """
        try:
            return self._device.query(  # type: ignore[union-attr]
                f"print({self._cmd_syntax}.read({file_number}, {read_action}))"
            )
        except AttributeError as error:
            msg = f"No TSPControl object was provided, unable to run the ``{self._cmd_syntax}.read()`` function."  # noqa: E501
            raise NoDeviceProvidedError(msg) from error

    def usbdriveexists(self) -> str:
        """Run the ``file.usbdriveexists()`` function.

        Description:
            - This function detects if a USB flash drive is inserted into the front-panel USB port.

        TSP Syntax:
            ```
            - file.usbdriveexists()
            ```

        Returns:
            The result of the function call.

        Raises:
            tm_devices.commands.NoDeviceProvidedError: Indicates that no device connection exists.
        """
        try:
            return self._device.query(  # type: ignore[union-attr]
                f"print({self._cmd_syntax}.usbdriveexists())"
            )
        except AttributeError as error:
            msg = f"No TSPControl object was provided, unable to run the ``{self._cmd_syntax}.usbdriveexists()`` function."  # noqa: E501
            raise NoDeviceProvidedError(msg) from error

    def write(self, file_number: int, string: str) -> None:
        """Run the ``file.write()`` function.

        Description:
            - This function writes data to a file on the USB flash drive.

        TSP Syntax:
            ```
            - file.write()
            ```

        Args:
            file_number: The file number returned from the file.open() function to write.
            string: A string that contains the data to write to the file.

        Raises:
            tm_devices.commands.NoDeviceProvidedError: Indicates that no device connection exists.
        """
        try:
            self._device.write(  # type: ignore[union-attr]
                f'{self._cmd_syntax}.write({file_number}, "{string}")'
            )
        except AttributeError as error:
            msg = f"No TSPControl object was provided, unable to run the ``{self._cmd_syntax}.write()`` function."  # noqa: E501
            raise NoDeviceProvidedError(msg) from error



# pyright: reportConstantRedefinition=none
"""The setup_1 commands module.

These commands are used in the following models:
SS3706A

THIS FILE IS AUTO-GENERATED, IT SHOULD NOT BE MANUALLY MODIFIED.

Please report an issue if one is found.

Attributes and Functions:
    ```
    - setup.poweron
    - setup.recall()
    - setup.save()
    ```
"""

from typing import Optional, TYPE_CHECKING, Union

from ..helpers import BaseTSPCmd, NoDeviceProvidedError

if TYPE_CHECKING:
    from tm_devices.driver_mixins.device_control.tsp_control import TSPControl


class Setup(BaseTSPCmd):
    """The ``setup`` command tree.

    Properties and methods:
        - ``.poweron``: The ``setup.poweron`` attribute.
        - ``.recall()``: The ``setup.recall()`` function.
        - ``.save()``: The ``setup.save()`` function.
    """

    def __init__(self, device: Optional["TSPControl"] = None, cmd_syntax: str = "setup") -> None:
        super().__init__(device, cmd_syntax)

    @property
    def poweron(self) -> str:
        """Access the ``setup.poweron`` attribute.

        Description:
            - This attribute specifies which saved setup to recall when the instrument is turned on.

        Usage:
            - Accessing this property will send the ``print(setup.poweron)`` query.
            - Setting this property to a value will send the ``setup.poweron = value`` command.

        TSP Syntax:
            ```
            - setup.poweron = value
            - print(setup.poweron)
            ```

        Raises:
            tm_devices.commands.NoDeviceProvidedError: Indicates that no device connection exists.
        """
        try:
            if self._device.command_syntax_enabled:  # type: ignore[union-attr]
                return self._cmd_syntax + ".poweron"
            return self._device.query(  # type: ignore[union-attr]
                f"print({self._cmd_syntax}.poweron)"
            )
        except AttributeError as error:
            msg = f"No TSPControl object was provided, unable to access the ``{self._cmd_syntax}.poweron`` attribute."  # noqa: E501
            raise NoDeviceProvidedError(msg) from error

    @poweron.setter
    def poweron(self, value: Union[str, float]) -> None:
        """Access the ``setup.poweron`` attribute.

        Description:
            - This attribute specifies which saved setup to recall when the instrument is turned on.

        Usage:
            - Accessing this property will send the ``print(setup.poweron)`` query.
            - Setting this property to a value will send the ``setup.poweron = value`` command.

        TSP Syntax:
            ```
            - setup.poweron = value
            - print(setup.poweron)
            ```

        Raises:
            tm_devices.commands.NoDeviceProvidedError: Indicates that no device connection exists.
        """
        try:
            if self._device.command_verification_enabled:  # type: ignore[union-attr]
                self._device.set_and_check(  # type: ignore[union-attr]
                    self._cmd_syntax + ".poweron", value
                )
            else:
                self._device.write(  # type: ignore[union-attr]
                    f"{self._cmd_syntax}.poweron = {value}"
                )
        except AttributeError as error:
            msg = f"No TSPControl object was provided, unable to access the ``{self._cmd_syntax}.poweron`` attribute."  # noqa: E501
            raise NoDeviceProvidedError(msg) from error

    def recall(self, id_: str) -> None:
        """Run the ``setup.recall()`` function.

        Description:
            - This function recalls settings from a saved setup.

        TSP Syntax:
            ```
            - setup.recall()
            ```

        Args:
            id_: An integer or string that specifies the location of the setup to recall.

        Raises:
            tm_devices.commands.NoDeviceProvidedError: Indicates that no device connection exists.
        """
        try:
            self._device.write(  # type: ignore[union-attr]
                f"{self._cmd_syntax}.recall({id_})"
            )
        except AttributeError as error:
            msg = f"No TSPControl object was provided, unable to run the ``{self._cmd_syntax}.recall()`` function."  # noqa: E501
            raise NoDeviceProvidedError(msg) from error

    def save(self, id_: Optional[str] = None) -> None:
        """Run the ``setup.save()`` function.

        Description:
            - This function saves the present setup as a user-saved setup.

        TSP Syntax:
            ```
            - setup.save()
            ```

        Args:
            id_ (optional): A string that specifies the path and file name to which to save the user
                setup on a USB flash drive ('/path/filename').

        Raises:
            tm_devices.commands.NoDeviceProvidedError: Indicates that no device connection exists.
        """
        try:
            function_args = ", ".join(
                str(x) for x in (f'"{id_}"' if id_ is not None else None,) if x is not None
            )
            self._device.write(  # type: ignore[union-attr]
                f"{self._cmd_syntax}.save({function_args})"
            )
        except AttributeError as error:
            msg = f"No TSPControl object was provided, unable to run the ``{self._cmd_syntax}.save()`` function."  # noqa: E501
            raise NoDeviceProvidedError(msg) from error
